Renamed the project from vimp to vimb.
authorDaniel Carl <danielcarl@gmx.de>
Sun, 17 Mar 2013 23:47:08 +0000 (00:47 +0100)
committerDaniel Carl <danielcarl@gmx.de>
Sun, 17 Mar 2013 23:47:08 +0000 (00:47 +0100)
There is already a software calles vimp so I think it will be better to rename
this little project.

26 files changed:
README.org
config.mk
doc/vimb.1.txt [new file with mode: 0644]
doc/vimp.1.txt [deleted file]
src/command.c
src/command.h
src/completion.c
src/completion.h
src/config.h
src/dom.c
src/dom.h
src/hints.c
src/hints.h
src/hints.js
src/history.c
src/history.h
src/keybind.c
src/keybind.h
src/main.c
src/main.h
src/searchengine.c
src/searchengine.h
src/setting.c
src/setting.h
src/util.c
src/util.h

index 519dc61..bd4151a 100644 (file)
@@ -1,6 +1,6 @@
-* Vimp
-  Vimp is a web browser that behaves like the Vimprobable but with some
-  paradigms from dwb and hopefully a cleaner code base. The goal of Vimp is to
+* vimb
+  Vimb is a web browser that behaves like the Vimprobable but with some
+  paradigms from dwb and hopefully a cleaner code base. The goal of Vimb is to
   build a completely keyboard-driven, efficient and pleasurable
   browsing-experience with low memory and cpu usage.
 ** Features
index f26da6f..f69cc80 100644 (file)
--- a/config.mk
+++ b/config.mk
@@ -1,7 +1,7 @@
 #----------------user/install options----------------
 VERSION = 0.1.4
 
-PROJECT = vimp
+PROJECT = vimb
 PREFIX  ?= /usr/local/
 BINDIR  ?= $(PREFIX)bin/
 MANDIR  ?= $(PREFIX)share/man/
diff --git a/doc/vimb.1.txt b/doc/vimb.1.txt
new file mode 100644 (file)
index 0000000..e28db42
--- /dev/null
@@ -0,0 +1,339 @@
+.\" Process this file with
+.\" groff -man -Tascii vimb.1
+.TH vimb 1 "16/02/2013" "vimb/VERSION" "Vimb Manual"
+.SH NAME
+vimb \- A modal web browser based on webkit thats inspired by vim the great editor.
+.SH SYNOPSIS
+.BI "vimb [" "OPTION" "] [" "URI" "]"
+.SH DESCRIPTION
+.B vimb
+is a webkit based web browser that behaves like the vimberator
+plugin for the firefox and usage paradigms from the great editor vim. The goal
+of vimb is to build a completely keyboard-driven, efficient and pleasurable
+browsing-experience.
+.SH OPTIONS
+Mandatory arguments to long options are mandatory for short options too.
+.TP
+.BI "-e, --embed " "WINID"
+.I WINID
+of an XEmbed-aware application, that vimb will use as its parent.
+.TP
+.B "-h, --help"
+Show help options.
+.TP
+.B "-v, --version"
+Print build and version information.
+.SH MODES
+vimb is modal an has following main modes:
+.TP
+.B Normal Mode
+The default mode. Pressing Escape always enter normal mode.
+.TP
+.B Insert Mode
+Used for editing text elements in a webpage.
+.TP
+.B Hint Mode
+Follow links, form fields and frames via hints.
+.TP
+.B Command Mode
+Execute vimb commands from the builtin inputbox (commandline).
+.TP
+.B Search Mode
+Search for strings within the current displayed page.
+.TP
+.B Insert Mode
+Used for editing text elements in a webpage.
+.SH COMMANDS
+Commands are a central part in vimb. They are used for nearly all things
+that could be done with this browser. Commands allow to set config variables,
+to assign keybindings and much more. Also the keybindings are only shortcut
+for the commands itself.
+
+Commands can be called in Insert Mode from the inputbox in the way like
+":[count]command[ param[=value]]". But some commands are not available in
+Command Mode and therefore not callable directly. To use them too, they must be
+bound to the keybinding.
+
+For example the command "hint-focus-next" is only available in hinting mode.
+To call it, it has to be bound to a key like "hmap <tab>=hint-focus-next" to
+be used.
+.SS Open
+.TP
+.BI "open [" URI ]
+Open the give \fIURI\fP into current window. If \fIURI\fP is empty the
+configured 'home-page' is opened.
+.TP
+.BI "tabopen [" URI ]
+Open the give \fIURI\fP into a new window. If \fIURI\fP is empty the
+configured 'home-page' is opened.
+.TP
+.B (tab)open-closed
+Open the last closed page.
+.TP
+.B (tab)open-clipboard
+Open the url from clipboard.
+.SS Input
+Switches the browser into Command Mode and prefill the inputbox on th bottom of
+the browser with various prefilled content.
+.TP
+.BI "input [" "TEXT" "]"
+Writes
+.I TEXT
+into to inputbox and switch to command mode. If no
+.I TEXT
+is given, print ':' into the inputbox.
+.TP
+.BI "inputuri [" "TEXT" "]"
+Writes
+.I TEXT\fR{URI}
+into to inputbox where {URL} is the current used url. This can be used to add
+keybindings to generate the tabopen command with current uri prefilled. If
+.I TEXT
+is not given use ':' instead.
+.SS Navigate
+Following commands are used to navigate within the browser history.
+.TP
+.BI [ N "]back"
+Move
+. I N
+steps back in browser history.
+.TP
+.BI [ N "]forward"
+Move \fIN\fP steps back in browser history.
+.TP
+.B reload
+Reload the current viewed url.
+.TP
+.B reload!
+Discard any caches and reload the current viewed url.
+.TP
+.B stop
+Stop loading the current url.
+.SS Scroll
+Following commands are used to scroll ad jump within the current view.
+.TP
+.BI [ N "]jumpleft"
+Scrolls the current view \fIN\fP steps to the left.
+.br
+If \fIN\fP is given jump to \fIN\fR% of the page from the left.
+.TP
+.BI [ N "]jumpright"
+Scrolls the current view to the right.
+.br
+If \fIN\fP is given jump to \fIN\fP% of the page from the left.
+.TP
+.BI [ N "]jumptop"
+Scrolls the current view to the top of page.
+.br
+If \fIN\fP is given, scroll to \fIN\fR% of the page.
+.TP
+.BI [ N "]jumpbottom"
+Scrolls the current view to the end of page.
+.br
+If \fIN\fP is given, scroll to \fIN\fR% of the page.
+.TP
+.BI [ N "]pageup"
+Scroll up the page \fIN\fP screens.
+.TP
+.BI [ N "]pagedown"
+Scroll down the page \fIN\fP screens.
+.TP
+.BI [ N "]halfpageup"
+Scroll up the page \fIN\fP half screens.
+.TP
+.BI [ N "]halfpagedown"
+Scroll down the page \fIN\fP half screens.
+.TP
+.BI [ N "]scrollleft"
+Scroll the page \fIN\fP times the "scrollstep" to the left.
+.TP
+.BI [ N "]scrollright"
+Scroll the page \fIN\fP times the "scrollstep" to the right.
+.TP
+.BI [ N "]scrollup"
+Scroll the page \fIN\fP times the "scrollstep" to the top.
+.TP
+.BI [ N "]scrolldown"
+Scroll the page \fIN\fP times the "scrollstep" to the end.
+.SS Keybinding
+To bind a command to a key sequence use the {n,i,c,h}map command. To map a
+keysequence to a command, use this format "nmap {[modkey]key}={command}[ params]".
+
+The modkey is a single simple char like "g". The key can also contain
+special keys and modifiers and is given in format like "<ctrl-o>", "<tab>",
+"<shift-tab>" or also a simple char like "G".
+
+Example:
+.br
+"hmap <shift-tab>=hint-focus-prev" to add focus next in in Hinting Mode.
+.br
+"nmap <shift-?>=input :foo" to write :foo into input box and switch to Command Mode.
+.br
+"hunmap <shift-tab>" To remove this keybinding use.
+
+If a keybinding is added, for the same key-sequence like another keybinding,
+the later added have precedence. If a keybinding is removed only that with the
+highest precedence will be removed and all other will still be active.
+.TP
+.B nmap
+Add a keybinding used in Normal Mode.
+.TP
+.B imap
+Add a keybinding used in Input Mode.
+.TP
+.B cmap
+Add a keybinding used in Command Mode.
+.TP
+.B hmap
+Add a keybinding used in Hint Mode.
+.TP
+.B smap
+Add keybinding used in Search Mode.
+.TP
+.B nunmap
+Remove a Normal Mode keybinding.
+.TP
+.B iunmap
+Remove a Input Mode keybinding.
+.TP
+.B cunmap
+Remove a Command Mode keybinding.
+.TP
+.B hunmap
+Remove a Hint Mode keybinding.
+.TP
+.B sunmap
+Remove a Search Mode keybinding.
+.SS Complete
+.TP
+.B complete
+Start a completion according to the current first chars in the inputbox. If
+complation is already started, switch to the next completion item.
+.TP
+.B complete-back
+If complation is already started, switch to the previous completion item.
+.SS Hints
+.TP
+.BI "hint-link [" PREFIX "], hint-link-new [" PREFIX ]
+Start hinting to open link into current or new window. If \fIPREFIX\fP is given,
+print this into the inputbox, default '.' and ','.
+.TP
+.BI "hint-input-open [" PREFIX "], hint-input-tabopen [" PREFIX ]
+Start hinting to fill the inputbox with ":open {hintedLinkUrl}" or ":tabopen
+{hintedLinkUrl}". If \fIPREFIX\fP is given, print this into the inputbox,
+default ';o' and ';t'.
+.TP
+.BI "hint-yank [" PREFIX ]
+Start hinting to yank the hinted link url into the primary and secondary
+clipboard. If \fIPREFIX\fP is given, print this into the inputbox, default ';y'.
+.TP
+.BI "hint-image-open [" PREFIX "], hint-image-tabopen [" PREFIX ]
+Start hinting to open images into current or new window. If \fIPREFIX\fP is
+given, print this into the inputbox, default ';i' and ';I'.
+.TP
+.B hint-focus-nex, hint-focus-prevt
+Focus next or previous hint.
+.SS Yank
+.TP
+.B yank-uri
+Yank the current url to the primary and secondary clipboard.
+.TP
+.B yank-selection
+Yank the selected text into the primary and secondary clipboard.
+.SS Searchengines
+Searchengines allows to query a searchengine instead of typing a full url. If
+a searchengine with shortcut 'dd' is defined you can use 'dd search terms' to
+perform a search query.
+.TP
+.BI "searchengine-add " "SHORTCUT" "=" "URI"
+Adds a searchengine with the \fISHORTCUT\fP and search \fIURI\fP. The uri must
+not contain more than one '%s' placeholder.
+
+Example: searchengine-add dl=https://duckduckgo.com/lite/?q=%s
+.SS Configuration
+.TP
+.BI "set " VAR = VALUE
+Set configuration values named by
+.IR VAR .
+To set boolean variable you should use 'on', 'off' or 'true'
+and 'false'. Colors are given as hexadecimal value like '#f57700'.
+.TP
+.BI "set " VAR ?
+Show the current set value of variable
+.IR VAR .
+.TP
+.BI "set " VAR !
+Toggle the value of boolean variable \fIVAR\fP and display the new set value.
+.SS Zoom
+.TP
+.BI [ N "]zoomin, [" N "]zoomout"
+Zoom \fIN\fP steps in or out of the current page \- effects only the text.
+.TP
+.BI [ N "]zoominfullt, [" N "]zoomoutfull"
+Zoom \fIN\fP steps in or out of the current page \- effecting all elements.
+.TP
+.B zoomreset
+Reset the zoomlevel to the default value.
+.SS Command-History
+.TP
+.BI [ N "]command-hist-prev, [" N "]command-hist-next"
+Prints the previous or next cammand from history into inputbox. If there is
+already text in the input box this will be used to get history items. A
+command is not a internal command, but every string entered into inputbox that
+begins with \fI[:/?]\fP. So the history contains real commands and search queries.
+.br
+Note that the history distinguishes between '/query' and '?query' what's not
+what the vim editor does.
+.SS Misc
+.TP
+.BI [ N "]search-forward, [" N "]search-backward"
+Search in current page forward or backward.
+.TP
+.B inspect
+Toggles the webinspector for current page. This is only available if the config
+"webinspector" is enabled.
+.TP
+.B quit
+Close the browser.
+.TP
+.B source
+Toggle between normal view and source view for the current page.
+.SH FILES
+.I $XDG_CONFIG_HOME/vimb/global.conf
+.RS
+Global configuration that are read on startup of application. This is the
+right place to set keybindings and global style settings for vimb.
+.RE
+.I $XDG_CONFIG_HOME/vimb/local.conf
+.RS
+Local configuration that are process every time a new window is opened. This
+will be mainly used to apply webkit settings for the new browser window.
+.RE
+.I $XDG_CONFIG_HOME/vimb/cookies
+.RS
+Cookie store file.
+.RE
+.I $XDG_CONFIG_HOME/vimb/closed
+.RS
+Holds the URI of the last closed browser window.
+.RE
+.I $XDG_CONFIG_HOME/vimb/history
+.RS
+This file holds the history of opened URIs. Note that this file is only
+written if last window of the browser is closed.
+.RE
+.I $XDG_CONFIG_HOME/vimb/scripts.js
+.RS
+This file can be used to run user scripts, that are injected into every paged
+that is opened.
+.RE
+.I $XDG_CONFIG_HOME/vimb/style.css
+.RS
+File for userdefined css styles. These file is used if the config variable
+'stylesheet' is enabled.
+.RE
+.SH "REPORTING BUGS"
+Report bugs to the main project page on
+.IR https://github.com/fanglingsu/vimb/issues .
+.SH AUTHOR
+Daniel Carl
diff --git a/doc/vimp.1.txt b/doc/vimp.1.txt
deleted file mode 100644 (file)
index eeacb44..0000000
+++ /dev/null
@@ -1,339 +0,0 @@
-.\" Process this file with
-.\" groff -man -Tascii vimp.1
-.TH vimp 1 "16/02/2013" "vimp/VERSION" "Vimp Manual"
-.SH NAME
-vimp \- A modal web browser based on webkit thats inspired by vim the great editor.
-.SH SYNOPSIS
-.BI "vimp [" "OPTION" "] [" "URI" "]"
-.SH DESCRIPTION
-.B vimp
-is a webkit based web browser that behaves like the vimperator
-plugin for the firefox and usage paradigms from the great editor vim. The goal
-of vimp is to build a completely keyboard-driven, efficient and pleasurable
-browsing-experience.
-.SH OPTIONS
-Mandatory arguments to long options are mandatory for short options too.
-.TP
-.BI "-e, --embed " "WINID"
-.I WINID
-of an XEmbed-aware application, that vimp will use as its parent.
-.TP
-.B "-h, --help"
-Show help options.
-.TP
-.B "-v, --version"
-Print build and version information.
-.SH MODES
-vimp is modal an has following main modes:
-.TP
-.B Normal Mode
-The default mode. Pressing Escape always enter normal mode.
-.TP
-.B Insert Mode
-Used for editing text elements in a webpage.
-.TP
-.B Hint Mode
-Follow links, form fields and frames via hints.
-.TP
-.B Command Mode
-Execute vimp commands from the builtin inputbox (commandline).
-.TP
-.B Search Mode
-Search for strings within the current displayed page.
-.TP
-.B Insert Mode
-Used for editing text elements in a webpage.
-.SH COMMANDS
-Commands are a central part in vimp. They are used for nearly all things
-that could be done with this browser. Commands allow to set config variables,
-to assign keybindings and much more. Also the keybindings are only shortcut
-for the commands itself.
-
-Commands can be called in Insert Mode from the inputbox in the way like
-":[count]command[ param[=value]]". But some commands are not available in
-Command Mode and therefore not callable directly. To use them too, they must be
-bound to the keybinding.
-
-For example the command "hint-focus-next" is only available in hinting mode.
-To call it, it has to be bound to a key like "hmap <tab>=hint-focus-next" to
-be used.
-.SS Open
-.TP
-.BI "open [" URI ]
-Open the give \fIURI\fP into current window. If \fIURI\fP is empty the
-configured 'home-page' is opened.
-.TP
-.BI "tabopen [" URI ]
-Open the give \fIURI\fP into a new window. If \fIURI\fP is empty the
-configured 'home-page' is opened.
-.TP
-.B (tab)open-closed
-Open the last closed page.
-.TP
-.B (tab)open-clipboard
-Open the url from clipboard.
-.SS Input
-Switches the browser into Command Mode and prefill the inputbox on th bottom of
-the browser with various prefilled content.
-.TP
-.BI "input [" "TEXT" "]"
-Writes
-.I TEXT
-into to inputbox and switch to command mode. If no
-.I TEXT
-is given, print ':' into the inputbox.
-.TP
-.BI "inputuri [" "TEXT" "]"
-Writes
-.I TEXT\fR{URI}
-into to inputbox where {URL} is the current used url. This can be used to add
-keybindings to generate the tabopen command with current uri prefilled. If
-.I TEXT
-is not given use ':' instead.
-.SS Navigate
-Following commands are used to navigate within the browser history.
-.TP
-.BI [ N "]back"
-Move
-. I N
-steps back in browser history.
-.TP
-.BI [ N "]forward"
-Move \fIN\fP steps back in browser history.
-.TP
-.B reload
-Reload the current viewed url.
-.TP
-.B reload!
-Discard any caches and reload the current viewed url.
-.TP
-.B stop
-Stop loading the current url.
-.SS Scroll
-Following commands are used to scroll ad jump within the current view.
-.TP
-.BI [ N "]jumpleft"
-Scrolls the current view \fIN\fP steps to the left.
-.br
-If \fIN\fP is given jump to \fIN\fR% of the page from the left.
-.TP
-.BI [ N "]jumpright"
-Scrolls the current view to the right.
-.br
-If \fIN\fP is given jump to \fIN\fP% of the page from the left.
-.TP
-.BI [ N "]jumptop"
-Scrolls the current view to the top of page.
-.br
-If \fIN\fP is given, scroll to \fIN\fR% of the page.
-.TP
-.BI [ N "]jumpbottom"
-Scrolls the current view to the end of page.
-.br
-If \fIN\fP is given, scroll to \fIN\fR% of the page.
-.TP
-.BI [ N "]pageup"
-Scroll up the page \fIN\fP screens.
-.TP
-.BI [ N "]pagedown"
-Scroll down the page \fIN\fP screens.
-.TP
-.BI [ N "]halfpageup"
-Scroll up the page \fIN\fP half screens.
-.TP
-.BI [ N "]halfpagedown"
-Scroll down the page \fIN\fP half screens.
-.TP
-.BI [ N "]scrollleft"
-Scroll the page \fIN\fP times the "scrollstep" to the left.
-.TP
-.BI [ N "]scrollright"
-Scroll the page \fIN\fP times the "scrollstep" to the right.
-.TP
-.BI [ N "]scrollup"
-Scroll the page \fIN\fP times the "scrollstep" to the top.
-.TP
-.BI [ N "]scrolldown"
-Scroll the page \fIN\fP times the "scrollstep" to the end.
-.SS Keybinding
-To bind a command to a key sequence use the {n,i,c,h}map command. To map a
-keysequence to a command, use this format "nmap {[modkey]key}={command}[ params]".
-
-The modkey is a single simple char like "g". The key can also contain
-special keys and modifiers and is given in format like "<ctrl-o>", "<tab>",
-"<shift-tab>" or also a simple char like "G".
-
-Example:
-.br
-"hmap <shift-tab>=hint-focus-prev" to add focus next in in Hinting Mode.
-.br
-"nmap <shift-?>=input :foo" to write :foo into input box and switch to Command Mode.
-.br
-"hunmap <shift-tab>" To remove this keybinding use.
-
-If a keybinding is added, for the same key-sequence like another keybinding,
-the later added have precedence. If a keybinding is removed only that with the
-highest precedence will be removed and all other will still be active.
-.TP
-.B nmap
-Add a keybinding used in Normal Mode.
-.TP
-.B imap
-Add a keybinding used in Input Mode.
-.TP
-.B cmap
-Add a keybinding used in Command Mode.
-.TP
-.B hmap
-Add a keybinding used in Hint Mode.
-.TP
-.B smap
-Add keybinding used in Search Mode.
-.TP
-.B nunmap
-Remove a Normal Mode keybinding.
-.TP
-.B iunmap
-Remove a Input Mode keybinding.
-.TP
-.B cunmap
-Remove a Command Mode keybinding.
-.TP
-.B hunmap
-Remove a Hint Mode keybinding.
-.TP
-.B sunmap
-Remove a Search Mode keybinding.
-.SS Complete
-.TP
-.B complete
-Start a completion according to the current first chars in the inputbox. If
-complation is already started, switch to the next completion item.
-.TP
-.B complete-back
-If complation is already started, switch to the previous completion item.
-.SS Hints
-.TP
-.BI "hint-link [" PREFIX "], hint-link-new [" PREFIX ]
-Start hinting to open link into current or new window. If \fIPREFIX\fP is given,
-print this into the inputbox, default '.' and ','.
-.TP
-.BI "hint-input-open [" PREFIX "], hint-input-tabopen [" PREFIX ]
-Start hinting to fill the inputbox with ":open {hintedLinkUrl}" or ":tabopen
-{hintedLinkUrl}". If \fIPREFIX\fP is given, print this into the inputbox,
-default ';o' and ';t'.
-.TP
-.BI "hint-yank [" PREFIX ]
-Start hinting to yank the hinted link url into the primary and secondary
-clipboard. If \fIPREFIX\fP is given, print this into the inputbox, default ';y'.
-.TP
-.BI "hint-image-open [" PREFIX "], hint-image-tabopen [" PREFIX ]
-Start hinting to open images into current or new window. If \fIPREFIX\fP is
-given, print this into the inputbox, default ';i' and ';I'.
-.TP
-.B hint-focus-nex, hint-focus-prevt
-Focus next or previous hint.
-.SS Yank
-.TP
-.B yank-uri
-Yank the current url to the primary and secondary clipboard.
-.TP
-.B yank-selection
-Yank the selected text into the primary and secondary clipboard.
-.SS Searchengines
-Searchengines allows to query a searchengine instead of typing a full url. If
-a searchengine with shortcut 'dd' is defined you can use 'dd search terms' to
-perform a search query.
-.TP
-.BI "searchengine-add " "SHORTCUT" "=" "URI"
-Adds a searchengine with the \fISHORTCUT\fP and search \fIURI\fP. The uri must
-not contain more than one '%s' placeholder.
-
-Example: searchengine-add dl=https://duckduckgo.com/lite/?q=%s
-.SS Configuration
-.TP
-.BI "set " VAR = VALUE
-Set configuration values named by
-.IR VAR .
-To set boolean variable you should use 'on', 'off' or 'true'
-and 'false'. Colors are given as hexadecimal value like '#f57700'.
-.TP
-.BI "set " VAR ?
-Show the current set value of variable
-.IR VAR .
-.TP
-.BI "set " VAR !
-Toggle the value of boolean variable \fIVAR\fP and display the new set value.
-.SS Zoom
-.TP
-.BI [ N "]zoomin, [" N "]zoomout"
-Zoom \fIN\fP steps in or out of the current page \- effects only the text.
-.TP
-.BI [ N "]zoominfullt, [" N "]zoomoutfull"
-Zoom \fIN\fP steps in or out of the current page \- effecting all elements.
-.TP
-.B zoomreset
-Reset the zoomlevel to the default value.
-.SS Command-History
-.TP
-.BI [ N "]command-hist-prev, [" N "]command-hist-next"
-Prints the previous or next cammand from history into inputbox. If there is
-already text in the input box this will be used to get history items. A
-command is not a internal command, but every string entered into inputbox that
-begins with \fI[:/?]\fP. So the history contains real commands and search queries.
-.br
-Note that the history distinguishes between '/query' and '?query' what's not
-what the vim editor does.
-.SS Misc
-.TP
-.BI [ N "]search-forward, [" N "]search-backward"
-Search in current page forward or backward.
-.TP
-.B inspect
-Toggles the webinspector for current page. This is only available if the config
-"webinspector" is enabled.
-.TP
-.B quit
-Close the browser.
-.TP
-.B source
-Toggle between normal view and source view for the current page.
-.SH FILES
-.I $XDG_CONFIG_HOME/vimp/global.conf
-.RS
-Global configuration that are read on startup of application. This is the
-right place to set keybindings and global style settings for vimp.
-.RE
-.I $XDG_CONFIG_HOME/vimp/local.conf
-.RS
-Local configuration that are process every time a new window is opened. This
-will be mainly used to apply webkit settings for the new browser window.
-.RE
-.I $XDG_CONFIG_HOME/vimp/cookies
-.RS
-Cookie store file.
-.RE
-.I $XDG_CONFIG_HOME/vimp/closed
-.RS
-Holds the URI of the last closed browser window.
-.RE
-.I $XDG_CONFIG_HOME/vimp/history
-.RS
-This file holds the history of opened URIs. Note that this file is only
-written if last window of the browser is closed.
-.RE
-.I $XDG_CONFIG_HOME/vimp/scripts.js
-.RS
-This file can be used to run user scripts, that are injected into every paged
-that is opened.
-.RE
-.I $XDG_CONFIG_HOME/vimp/style.css
-.RS
-File for userdefined css styles. These file is used if the config variable
-'stylesheet' is enabled.
-.RE
-.SH "REPORTING BUGS"
-Report bugs to the main project page on
-.IR https://github.com/fanglingsu/vimp/issues .
-.SH AUTHOR
-Daniel Carl
index 9cd7608..ce40dc8 100644 (file)
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index c0062f7..6623b00 100644 (file)
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index c5ae3dd..7854ce0 100644 (file)
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 5a18a2b..b312679 100644 (file)
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 9be97d0..648aa43 100644 (file)
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 260c506..a71d4cf 100644 (file)
--- a/src/dom.c
+++ b/src/dom.c
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 20b1bae..27a7210 100644 (file)
--- a/src/dom.h
+++ b/src/dom.h
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index db89903..b823af3 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
@@ -76,7 +76,7 @@ void hints_create(Client* c, const char* input, guint mode, const guint prefixLe
         }
 
         js = g_strdup_printf(
-            "%s = new VimpHints('%c', '%c', '%s', '%s', '%s', '%s', %d);",
+            "%s = new VimbHints('%c', '%c', '%s', '%s', '%s', '%s', %d);",
             HINT_VAR, type, usage,
             style->hint_bg,
             style->hint_bg_focus,
index 14e682d..6f3c720 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index aeceea7..542a386 100644 (file)
@@ -1,6 +1,6 @@
 /* mode: l - links, i - images */
 /* usage: O - open, T - open in new window, U - use source */
-function VimpHints(mode, usage, bg, bgf, fg, style, maxHints)
+function VimbHints(mode, usage, bg, bgf, fg, style, maxHints)
 {
     "use strict";
     var hClass      = "__hint";
index d74dd7a..52175f7 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index ad48a3f..a80dd19 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 2fbcba1..44229d4 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 7ca7b69..7d97d11 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index d762647..43be57d 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
@@ -721,16 +721,16 @@ static Client* vp_client_new(void)
         gui->window = gtk_plug_new(core.embed);
     } else {
         gui->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-        gtk_window_set_wmclass(GTK_WINDOW(gui->window), "vimp", "Vimp");
-        gtk_window_set_role(GTK_WINDOW(gui->window), "Vimp");
+        gtk_window_set_wmclass(GTK_WINDOW(gui->window), "vimb", "Vimb");
+        gtk_window_set_role(GTK_WINDOW(gui->window), "Vimb");
     }
 
     GdkGeometry hints = {10, 10};
     gtk_window_set_default_size(GTK_WINDOW(gui->window), 640, 480);
-    gtk_window_set_title(GTK_WINDOW(gui->window), "vimp");
+    gtk_window_set_title(GTK_WINDOW(gui->window), "vimb");
     gtk_window_set_geometry_hints(GTK_WINDOW(gui->window), NULL, &hints, GDK_HINT_MIN_SIZE);
     gtk_window_set_icon(GTK_WINDOW(gui->window), NULL);
-    gtk_widget_set_name(GTK_WIDGET(gui->window), "vimp");
+    gtk_widget_set_name(GTK_WIDGET(gui->window), "vimb");
 
     /* Create a browser instance */
     gui->webview = WEBKIT_WEB_VIEW(webkit_web_view_new());
@@ -951,7 +951,7 @@ static gboolean vp_download_requested_cb(WebKitWebView* view, WebKitDownload* do
 
     const char* filename = webkit_download_get_suggested_filename(download);
     if (!filename) {
-        filename = "vimp_donwload";
+        filename = "vimb_donwload";
     }
 
     /* prepare the download target path */
index d6475e7..db2a5e7 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 7d0fac7..0a267f9 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index c50b4be..d9079cc 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index dd03126..61e8c61 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
@@ -81,7 +81,7 @@ static Setting default_settings[] = {
     {"seriffont", "serif-font-family", TYPE_CHAR, setting_webkit, {.s = "serif"}, FALSE},
     {"spelllang", "spell-checking-languages", TYPE_CHAR, setting_webkit, {.s = NULL}, FALSE},
     {NULL, "tab-key-cycles-through-elements", TYPE_BOOLEAN, setting_webkit, {.i = 1}, FALSE},
-    {"useragent", "user-agent", TYPE_CHAR, setting_webkit, {.s = "vimp/" VERSION " (X11; Linux i686) AppleWebKit/535.22+ Compatible (Safari)"}, FALSE},
+    {"useragent", "user-agent", TYPE_CHAR, setting_webkit, {.s = "vimb/" VERSION " (X11; Linux i686) AppleWebKit/535.22+ Compatible (Safari)"}, FALSE},
     {"zoomstep", "zoom-step", TYPE_FLOAT, setting_webkit, {.i = 100000}, FALSE},
 
     /* internal variables */
@@ -119,8 +119,8 @@ static Setting default_settings[] = {
     {NULL, "hint-fg", TYPE_CHAR, setting_hint_style, {.s = "#000"}, TRUE},
     {NULL, "hint-style", TYPE_CHAR, setting_hint_style, {.s = "position:absolute;z-index:100000;font-family:monospace;font-weight:bold;font-size:10px;color:#000;background-color:#fff;margin:0;padding:0px 1px;border:1px solid #444;opacity:0.7;"}, TRUE},
     {NULL, "ca-bundle", TYPE_CHAR, setting_ca_bundle, {.s = "/etc/ssl/certs/ca-certificates.crt"}, TRUE},
-    {NULL, "home-page", TYPE_CHAR, setting_home_page, {.s = "https://github.com/fanglingsu/vimp"}, TRUE},
-    {NULL, "download-path", TYPE_CHAR, setting_download_path, {.s = "/tmp/vimp"}, TRUE},
+    {NULL, "home-page", TYPE_CHAR, setting_home_page, {.s = "https://github.com/fanglingsu/vimb"}, TRUE},
+    {NULL, "download-path", TYPE_CHAR, setting_download_path, {.s = "/tmp/vimb"}, TRUE},
     {NULL, "history-max-items", TYPE_INTEGER, setting_history_max_items, {.i = 500}, TRUE},
 };
 
index 713c8aa..618f818 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
index 9a30e14..400d000 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
@@ -23,7 +23,7 @@
 
 char* util_get_config_dir(void)
 {
-    char *path = g_build_filename(g_get_user_config_dir(), "vimp", NULL);
+    char *path = g_build_filename(g_get_user_config_dir(), "vimb", NULL);
     util_create_dir_if_not_exists(path);
 
     return path;
@@ -31,7 +31,7 @@ char* util_get_config_dir(void)
 
 char* util_get_cache_dir(void)
 {
-    char *path = g_build_filename(g_get_user_cache_dir(), "vimp", NULL);
+    char *path = g_build_filename(g_get_user_cache_dir(), "vimb", NULL);
     util_create_dir_if_not_exists(path);
 
     return path;
index d69a532..5a52031 100644 (file)
@@ -1,5 +1,5 @@
 /**
* vimp - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
  *
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl
@@ -1,5 +1,5 @@
 /**
- * vimp - a webkit based vim like browser.
+ * vimb - a webkit based vim like browser.
  *
  * Copyright (C) 2012-2013 Daniel Carl